@@ -6,7 +6,7 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class CutefishProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__('Cutefish', ProfileType.DesktopEnv, description='')
+		super().__init__('Cutefish', ProfileType.DesktopEnv)
 
 	@property
 	@override
@@ -18,5 +18,5 @@ class CutefishProfile(XorgProfile):
 
 	@property
 	@override
-	def default_greeter_type(self) -> GreeterType | None:
+	def default_greeter_type(self) -> GreeterType:
 		return GreeterType.Sddm
