@@ -6,7 +6,7 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class I3wmProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__('i3-wm', ProfileType.WindowMgr, description='')
+		super().__init__('i3-wm', ProfileType.WindowMgr)
 
 	@property
 	@override
@@ -25,5 +25,5 @@ class I3wmProfile(XorgProfile):
 
 	@property
 	@override
-	def default_greeter_type(self) -> GreeterType | None:
+	def default_greeter_type(self) -> GreeterType:
 		return GreeterType.Lightdm
