@@ -38,12 +38,14 @@ from ..models.device_model import (
 	_DeviceInfo,
 	_PartitionInfo,
 )
+from ..models.users import Password
 from ..output import debug, error, info, log
 from ..utils.util import is_subpath
 from .utils import (
 	find_lsblk_info,
 	get_all_lsblk_info,
 	get_lsblk_info,
+	umount,
 )
 
 
@@ -224,8 +226,8 @@ class DeviceHandler:
 			mountpoint = self._TMP_BTRFS_MOUNT
 		else:
 			# when multiple subvolumes are mounted then the lsblk output may look like
-			# "mountpoint": "/mnt/archinstall/.snapshots"
-			# "mountpoints": ["/mnt/archinstall/.snapshots", "/mnt/archinstall/home", ..]
+			# "mountpoint": "/mnt/archinstall/var/log"
+			# "mountpoints": ["/mnt/archinstall/var/log", "/mnt/archinstall/home", ..]
 			# so we'll determine the minimum common path and assume that's the root
 			try:
 				common_path = os.path.commonpath(lsblk_info.mountpoints)
@@ -256,7 +258,7 @@ class DeviceHandler:
 			subvol_infos.append(_BtrfsSubvolumeInfo(name, sub_vol_mountpoint))
 
 		if not lsblk_info.mountpoint:
-			self.umount(dev_path)
+			umount(dev_path)
 
 		return subvol_infos
 
@@ -307,7 +309,7 @@ class DeviceHandler:
 		self,
 		dev_path: Path,
 		mapper_name: str | None,
-		enc_password: str,
+		enc_password: Password | None,
 		lock_after_create: bool = True
 	) -> Luks2:
 		luks_handler = Luks2(
@@ -338,6 +340,9 @@ class DeviceHandler:
 		fs_type: FilesystemType,
 		enc_conf: DiskEncryption
 	) -> None:
+		if not enc_conf.encryption_password:
+			raise ValueError('No encryption password provided')
+
 		luks_handler = Luks2(
 			dev_path,
 			mapper_name=mapper_name,
@@ -631,7 +636,7 @@ class DeviceHandler:
 				except SysCallError as err:
 					raise DiskError(f'Could not set compress attribute at {subvol_path}: {err}')
 
-		self.umount(path)
+		umount(path)
 
 	def create_btrfs_volumes(
 		self,
@@ -673,12 +678,17 @@ class DeviceHandler:
 
 			SysCommand(f"btrfs subvolume create -p {subvol_path}")
 
-		self.umount(dev_path)
+		umount(dev_path)
 
 		if luks_handler is not None and luks_handler.mapper_dev is not None:
 			luks_handler.lock()
 
-	def unlock_luks2_dev(self, dev_path: Path, mapper_name: str, enc_password: str) -> Luks2:
+	def unlock_luks2_dev(
+		self,
+		dev_path: Path,
+		mapper_name: str,
+		enc_password: Password | None
+	) -> Luks2:
 		luks_handler = Luks2(dev_path, mapper_name=mapper_name, password=enc_password)
 
 		if not luks_handler.is_unlocked():
@@ -701,7 +711,7 @@ class DeviceHandler:
 			if partition.fs_type == FilesystemType.Crypto_luks:
 				Luks2(partition.path).lock()
 			else:
-				self.umount(partition.path, recursive=True)
+				umount(partition.path, recursive=True)
 
 	def partition(
 		self,
@@ -781,23 +791,6 @@ class DeviceHandler:
 		except SysCallError as err:
 			raise DiskError(f'Could not mount {dev_path}: {command}\n{err.message}')
 
-	def umount(self, mountpoint: Path, recursive: bool = False) -> None:
-		lsblk_info = get_lsblk_info(mountpoint)
-
-		if not lsblk_info.mountpoints:
-			return
-
-		debug(f'Partition {mountpoint} is currently mounted at: {[str(m) for m in lsblk_info.mountpoints]}')
-
-		cmd = ['umount']
-
-		if recursive:
-			cmd.append('-R')
-
-		for path in lsblk_info.mountpoints:
-			debug(f'Unmounting mountpoint: {path}')
-			SysCommand(cmd + [str(path)])
-
 	def detect_pre_mounted_mods(self, base_mountpoint: Path) -> list[DeviceModification]:
 		part_mods: dict[Path, list[PartitionModification]] = {}
 
