@@ -30,7 +30,8 @@ from archinstall.lib.models.device_model import (
 from archinstall.lib.output import debug
 from archinstall.tui.curses_menu import SelectMenu
 from archinstall.tui.menu_item import MenuItem, MenuItemGroup
-from archinstall.tui.types import Alignment, FrameProperties, Orientation, PreviewStyle, ResultType
+from archinstall.tui.result import ResultType
+from archinstall.tui.types import Alignment, FrameProperties, Orientation, PreviewStyle
 
 from ..output import FormattedOutput
 from ..utils.util import prompt_dir
@@ -45,7 +46,7 @@ if TYPE_CHECKING:
 
 def select_devices(preset: list[BDevice] | None = []) -> list[BDevice]:
 	def _preview_device_selection(item: MenuItem) -> str | None:
-		device: _DeviceInfo = item.get_value()
+		device = item.get_value()
 		dev = device_handler.get_device(device.path)
 
 		if dev and dev.partition_infos:
@@ -59,13 +60,12 @@ def select_devices(preset: list[BDevice] | None = []) -> list[BDevice]:
 	options = [d.device_info for d in devices]
 	presets = [p.device_info for p in preset]
 
-	group, header = MenuHelper.create_table(data=options)
+	group = MenuHelper(options).create_menu_group()
 	group.set_selected_by_value(presets)
 	group.set_preview_for_all(_preview_device_selection)
 
-	result = SelectMenu(
+	result = SelectMenu[_DeviceInfo](
 		group,
-		header=header,
 		alignment=Alignment.CENTER,
 		search_enabled=False,
 		multi=True,
@@ -81,7 +81,7 @@ def select_devices(preset: list[BDevice] | None = []) -> list[BDevice]:
 		case ResultType.Skip:
 			return preset
 		case ResultType.Selection:
-			selected_device_info: list[_DeviceInfo] = result.get_values()
+			selected_device_info = result.get_values()
 			selected_devices = []
 
 			for device in devices:
@@ -139,7 +139,7 @@ def select_disk_config(preset: DiskLayoutConfiguration | None = None) -> DiskLay
 	if preset:
 		group.set_selected_by_value(preset.config_type.display_msg())
 
-	result = SelectMenu(
+	result = SelectMenu[str](
 		group,
 		allow_skip=True,
 		alignment=Alignment.CENTER,
@@ -209,7 +209,7 @@ def select_lvm_config(
 	group = MenuItemGroup(items)
 	group.set_focus_by_value(preset_value)
 
-	result = SelectMenu(
+	result = SelectMenu[str](
 		group,
 		allow_reset=True,
 		allow_skip=True,
@@ -232,11 +232,9 @@ def select_lvm_config(
 def _boot_partition(sector_size: SectorSize, using_gpt: bool) -> PartitionModification:
 	flags = [PartitionFlag.BOOT]
 	size = Size(1, Unit.GiB, sector_size)
+	start = Size(1, Unit.MiB, sector_size)
 	if using_gpt:
-		start = Size(1, Unit.MiB, sector_size)
 		flags.append(PartitionFlag.ESP)
-	else:
-		start = Size(3, Unit.MiB, sector_size)
 
 	# boot partition
 	return PartitionModification(
@@ -262,7 +260,7 @@ def select_main_filesystem_format() -> FilesystemType:
 		items.append(MenuItem('ntfs', value=FilesystemType.Ntfs))
 
 	group = MenuItemGroup(items, sort_items=False)
-	result = SelectMenu(
+	result = SelectMenu[FilesystemType](
 		group,
 		alignment=Alignment.CENTER,
 		frame=FrameProperties.min('Filesystem'),
@@ -286,7 +284,7 @@ def select_mount_options() -> list[str]:
 		MenuItem(disable_cow, value=BtrfsMountOption.nodatacow.value),
 	]
 	group = MenuItemGroup(items, sort_items=False)
-	result = SelectMenu(
+	result = SelectMenu[str](
 		group,
 		header=prompt,
 		alignment=Alignment.CENTER,
@@ -337,7 +335,7 @@ def suggest_single_disk_layout(
 		prompt = str(_('Would you like to use BTRFS subvolumes with a default structure?')) + '\n'
 		group = MenuItemGroup.yes_no()
 		group.set_focus_by_value(MenuItem.yes().value)
-		result = SelectMenu(
+		result = SelectMenu[bool](
 			group,
 			header=prompt,
 			alignment=Alignment.CENTER,
@@ -362,15 +360,6 @@ def suggest_single_disk_layout(
 	available_space = available_space.align()
 
 	# Used for reference: https://wiki.archlinux.org/title/partitioning
-	# 2 MiB is unallocated for GRUB on BIOS. Potentially unneeded for other bootloaders?
-
-	# TODO: On BIOS, /boot partition is only needed if the drive will
-	# be encrypted, otherwise it is not recommended. We should probably
-	# add a check for whether the drive will be encrypted or not.
-
-	# Increase the UEFI partition if UEFI is detected.
-	# Also re-align the start to 1MiB since we don't need the first sectors
-	# like we do in MBR layouts where the boot loader is installed traditionally.
 
 	boot_partition = _boot_partition(sector_size, using_gpt)
 	device_modification.add_partition(boot_partition)
@@ -427,8 +416,7 @@ def suggest_single_disk_layout(
 			SubvolumeModification(Path('@'), Path('/')),
 			SubvolumeModification(Path('@home'), Path('/home')),
 			SubvolumeModification(Path('@log'), Path('/var/log')),
-			SubvolumeModification(Path('@pkg'), Path('/var/cache/pacman/pkg')),
-			SubvolumeModification(Path('@.snapshots'), Path('/.snapshots'))
+			SubvolumeModification(Path('@pkg'), Path('/var/cache/pacman/pkg'))
 		]
 		root_partition.btrfs_subvols = subvolumes
 	elif using_home_partition:
@@ -588,7 +576,7 @@ def suggest_lvm_layout(
 		group = MenuItemGroup.yes_no()
 		group.set_focus_by_value(MenuItem.yes().value)
 
-		result = SelectMenu(
+		result = SelectMenu[bool](
 			group,
 			header=prompt,
 			search_enabled=False,
@@ -606,8 +594,7 @@ def suggest_lvm_layout(
 			SubvolumeModification(Path('@'), Path('/')),
 			SubvolumeModification(Path('@home'), Path('/home')),
 			SubvolumeModification(Path('@log'), Path('/var/log')),
-			SubvolumeModification(Path('@pkg'), Path('/var/cache/pacman/pkg')),
-			SubvolumeModification(Path('@.snapshots'), Path('/.snapshots')),
+			SubvolumeModification(Path('@pkg'), Path('/var/cache/pacman/pkg'))
 		]
 
 		home_volume = False
