@@ -2,7 +2,8 @@ from typing import TYPE_CHECKING, override
 
 from archinstall.tui.curses_menu import SelectMenu
 from archinstall.tui.menu_item import MenuItem, MenuItemGroup
-from archinstall.tui.types import Alignment, FrameProperties, ResultType
+from archinstall.tui.result import ResultType
+from archinstall.tui.types import Alignment, FrameProperties
 
 from ..menu.abstract_menu import AbstractSubMenu
 from ..models.locale import LocaleConfiguration
@@ -16,7 +17,7 @@ if TYPE_CHECKING:
 	_: Callable[[str], DeferredTranslation]
 
 
-class LocaleMenu(AbstractSubMenu):
+class LocaleMenu(AbstractSubMenu[LocaleConfiguration]):
 	def __init__(
 		self,
 		locale_conf: LocaleConfiguration
@@ -84,7 +85,7 @@ def select_locale_lang(preset: str | None = None) -> str | None:
 	group = MenuItemGroup(items, sort_items=True)
 	group.set_focus_by_value(preset)
 
-	result = SelectMenu(
+	result = SelectMenu[str](
 		group,
 		alignment=Alignment.CENTER,
 		frame=FrameProperties.min(str(_('Locale language'))),
@@ -108,7 +109,7 @@ def select_locale_enc(preset: str | None = None) -> str | None:
 	group = MenuItemGroup(items, sort_items=True)
 	group.set_focus_by_value(preset)
 
-	result = SelectMenu(
+	result = SelectMenu[str](
 		group,
 		alignment=Alignment.CENTER,
 		frame=FrameProperties.min(str(_('Locale encoding'))),
@@ -140,7 +141,7 @@ def select_kb_layout(preset: str | None = None) -> str | None:
 	group = MenuItemGroup(items, sort_items=False)
 	group.set_focus_by_value(preset)
 
-	result = SelectMenu(
+	result = SelectMenu[str](
 		group,
 		alignment=Alignment.CENTER,
 		frame=FrameProperties.min(str(_('Keyboard layout'))),
