@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import curses
-import curses.panel
 import os
 import signal
 import sys
@@ -15,6 +14,7 @@ from typing import TYPE_CHECKING, Literal, override
 from ..lib.output import debug
 from .help import Help
 from .menu_item import MenuItem, MenuItemGroup, MenuItemsState
+from .result import Result, ResultType
 from .types import (
 	SCROLL_INTERVAL,
 	STYLE,
@@ -25,8 +25,6 @@ from .types import (
 	MenuKeys,
 	Orientation,
 	PreviewStyle,
-	Result,
-	ResultType,
 	ViewportEntry,
 	_FrameDim,
 )
@@ -37,7 +35,7 @@ if TYPE_CHECKING:
 	_: Callable[[str], DeferredTranslation]
 
 
-class AbstractCurses(metaclass=ABCMeta):
+class AbstractCurses[ValueT](metaclass=ABCMeta):
 	def __init__(self) -> None:
 		self._help_window = self._set_help_viewport()
 
@@ -46,7 +44,7 @@ class AbstractCurses(metaclass=ABCMeta):
 		pass
 
 	@abstractmethod
-	def kickoff(self, win: 'curses._CursesWindow') -> Result:
+	def kickoff(self, win: curses.window) -> Result[ValueT]:
 		pass
 
 	def clear_all(self) -> None:
@@ -73,7 +71,7 @@ class AbstractCurses(metaclass=ABCMeta):
 
 	def _confirm_interrupt(self, warning: str) -> bool:
 		while True:
-			result = SelectMenu(
+			result = SelectMenu[bool](
 				MenuItemGroup.yes_no(),
 				header=warning,
 				alignment=Alignment.CENTER,
@@ -103,18 +101,12 @@ class AbstractCurses(metaclass=ABCMeta):
 		entries += [ViewportEntry(f'   {e}   ', idx + 1, 0, STYLE.NORMAL) for idx, e in enumerate(lines)]
 		self._help_window.update(entries, 0)
 
-	def get_header_entries(
-		self,
-		header: str | None,
-		offset: int = 0
-	) -> list[ViewportEntry]:
-		cur_row = 0
+	def get_header_entries(self, header: str) -> list[ViewportEntry]:
 		full_header = []
+		rows = header.split('\n')
 
-		if header:
-			for line in header.split('\n'):
-				full_header += [ViewportEntry(line, cur_row, offset, STYLE.NORMAL)]
-				cur_row += 1
+		for cur_row, line in enumerate(rows):
+			full_header += [ViewportEntry(line, cur_row, 0, STYLE.NORMAL)]
 
 		return full_header
 
@@ -123,7 +115,7 @@ class AbstractViewport:
 	def __init__(self) -> None:
 		pass
 
-	def add_str(self, screen: 'curses._CursesWindow', row: int, col: int, text: str, color: STYLE) -> None:
+	def add_str(self, screen: curses.window, row: int, col: int, text: str, color: STYLE) -> None:
 		try:
 			screen.addstr(row, col, text, Tui.t().get_color(color))
 		except curses.error:
@@ -323,8 +315,8 @@ class EditViewport(AbstractViewport):
 		self._alignment = alignment
 		self._hide_input = hide_input
 
-		self._main_win: 'curses._CursesWindow | None' = None
-		self._edit_win: 'curses._CursesWindow | None' = None
+		self._main_win: curses.window | None = None
+		self._edit_win: curses.window | None = None
 		self._textbox: Textbox | None = None
 
 		self._init_wins()
@@ -463,7 +455,7 @@ class Viewport(AbstractViewport):
 		self._main_win.refresh()
 
 
-class EditMenu(AbstractCurses):
+class EditMenu(AbstractCurses[str]):
 	def __init__(
 		self,
 		title: str,
@@ -482,11 +474,15 @@ class EditMenu(AbstractCurses):
 		self._max_height, self._max_width = Tui.t().max_yx
 
 		self._header = header
+
+		self._header_entries = []
+		if header:
+			self._header_entries = self.get_header_entries(header)
+
 		self._validator = validator
 		self._allow_skip = allow_skip
 		self._allow_reset = allow_reset
 		self._interrupt_warning = reset_warning_msg
-		self._headers = self.get_header_entries(header, offset=0)
 		self._alignment = alignment
 		self._edit_width = edit_width
 		self._default_text = default_text
@@ -508,7 +504,7 @@ class EditMenu(AbstractCurses):
 
 		self._init_viewports()
 
-		self._last_state: Result | None = None
+		self._last_state: Result[str] | None = None
 		self._help_active = False
 		self._real_input = default_text or ""
 
@@ -518,8 +514,8 @@ class EditMenu(AbstractCurses):
 		self._help_vp = Viewport(self._max_width, 2, 0, y_offset)
 		y_offset += 2
 
-		if self._headers:
-			header_height = len(self._headers)
+		if self._header_entries:
+			header_height = len(self._header_entries)
 			self._header_vp = Viewport(self._max_width, header_height, 0, y_offset, alignment=self._alignment)
 			y_offset += header_height
 
@@ -538,7 +534,7 @@ class EditMenu(AbstractCurses):
 		y_offset += 3
 		self._info_vp = Viewport(self._max_width, 1, 0, y_offset, alignment=self._alignment)
 
-	def input(self) -> Result:
+	def input(self) -> Result[str]:
 		result = Tui.run(self)
 
 		assert not result.has_item() or isinstance(result.text(), str)
@@ -583,8 +579,8 @@ class EditMenu(AbstractCurses):
 		if self._help_vp:
 			self._help_vp.update([self.help_entry()], 0)
 
-		if self._headers and self._header_vp:
-			self._header_vp.update(self._headers, 0)
+		if self._header_entries and self._header_vp:
+			self._header_vp.update(self._header_entries, 0)
 
 		if self._input_vp:
 			self._input_vp.update()
@@ -595,7 +591,7 @@ class EditMenu(AbstractCurses):
 			self._input_vp.edit(default_text=self._default_text)
 
 	@override
-	def kickoff(self, win: 'curses._CursesWindow') -> Result:
+	def kickoff(self, win: curses.window) -> Result[str]:
 		try:
 			self._draw()
 		except KeyboardInterrupt:
@@ -682,7 +678,7 @@ class EditMenu(AbstractCurses):
 		return True
 
 
-class SelectMenu(AbstractCurses):
+class SelectMenu[ValueT](AbstractCurses[ValueT]):
 	def __init__(
 		self,
 		group: MenuItemGroup,
@@ -722,9 +718,12 @@ class SelectMenu(AbstractCurses):
 		self._interrupt_warning = reset_warning_msg
 		self._header = header
 
-		header_offset = self._get_header_offset(header)
-
-		self._headers = self.get_header_entries(header, offset=header_offset)
+		# TODO: Remove the inline annotation after upgrading to mypy 1.16.0
+		# The inline annotation is needed to avoid a crash in 1.15.0:
+		#  RuntimeError: Partial type "<partial list[?]>" cannot be checked with "issubtype()"
+		self._header_entries: list[ViewportEntry] = []
+		if header:
+			self._header_entries = self.get_header_entries(header)
 
 		if self._interrupt_warning is None:
 			self._interrupt_warning = str(_('Are you sure you want to reset this setting?')) + '\n'
@@ -755,29 +754,13 @@ class SelectMenu(AbstractCurses):
 			with_frame=self._frame is not None
 		)
 
-	def _get_header_offset(self, header: str | None) -> int:
-		# WARNING: any changes here will impact the list manager table view
-		if self._orientation == Orientation.HORIZONTAL:
-			return 0
-
-		lines = header.split('\n') if header else []
-		table_header = [line for line in lines if '-' in line]
-
-		longest_header = len(table_header[0]) if table_header else 0
-		longest_entry = self._item_group.get_max_width()
-
-		delta = longest_header - longest_entry
-		offset = delta + 2  # 2 because it seems to align it...
-
-		return offset
-
-	def run(self) -> Result:
+	def run(self) -> Result[ValueT]:
 		result = Tui.run(self)
 		self._clear_all()
 		return result
 
 	@override
-	def kickoff(self, win: 'curses._CursesWindow') -> Result:
+	def kickoff(self, win: curses.window) -> Result[ValueT]:
 		self._draw()
 
 		while True:
@@ -829,8 +812,8 @@ class SelectMenu(AbstractCurses):
 		self._help_vp = Viewport(self._max_width, 2, 0, y_offset)
 		y_offset += 2
 
-		if self._headers:
-			header_height = len(self._headers)
+		if self._header_entries:
+			header_height = len(self._header_entries)
 			self._header_vp = Viewport(
 				self._max_width,
 				header_height,
@@ -962,7 +945,7 @@ class SelectMenu(AbstractCurses):
 			self._update_viewport(self._help_vp, [self.help_entry()])
 
 		if self._header_vp:
-			self._update_viewport(self._header_vp, self._headers)
+			self._update_viewport(self._header_vp, self._header_entries)
 
 		if self._menu_vp:
 			self._update_viewport(self._menu_vp, vp_entries)
@@ -1128,7 +1111,9 @@ class SelectMenu(AbstractCurses):
 			self._prev_scroll_pos = 0
 
 	def _multi_prefix(self, item: MenuItem) -> str:
-		if self._item_group.is_item_selected(item):
+		if item.read_only:
+			return '    '
+		elif self._item_group.is_item_selected(item):
 			return '[x] '
 		else:
 			return '[ ] '
@@ -1139,7 +1124,7 @@ class SelectMenu(AbstractCurses):
 		else:
 			return False
 
-	def _process_input_key(self, key: int) -> Result | None:
+	def _process_input_key(self, key: int) -> Result[ValueT] | None:
 		key_handles = MenuKeys.from_ord(key)
 
 		if self._help_active:
@@ -1256,7 +1241,7 @@ class Tui:
 		self.stop()
 
 	@property
-	def screen(self) -> 'curses._CursesWindow':
+	def screen(self) -> curses.window:
 		return self._screen
 
 	@staticmethod
@@ -1341,7 +1326,7 @@ class Tui:
 		return self._screen.getmaxyx()
 
 	@staticmethod
-	def run(component: AbstractCurses) -> Result:
+	def run[ValueT](component: AbstractCurses[ValueT]) -> Result[ValueT]:
 		if Tui._t is None:
 			tui = Tui().init()
 			tui.screen.clear()
@@ -1357,7 +1342,7 @@ class Tui:
 		if hasattr(self, '_component') and self._component is not None:  # pylint: disable=no-member
 			self._component.resize_win()  # pylint: disable=no-member
 
-	def _main_loop(self, component: AbstractCurses) -> Result:
+	def _main_loop[ValueT](self, component: AbstractCurses[ValueT]) -> Result[ValueT]:
 		self._screen.refresh()
 		return component.kickoff(self._screen)
 
