@@ -5,7 +5,7 @@ from dataclasses import dataclass, field
 from functools import cached_property
 from typing import TYPE_CHECKING, Any, ClassVar
 
-from ..lib.output import unicode_ljust
+from ..lib.utils.unicode import unicode_ljust
 
 if TYPE_CHECKING:
 	from archinstall.lib.translationhandler import DeferredTranslation
@@ -19,6 +19,7 @@ class MenuItem:
 	value: Any | None = None
 	action: Callable[[Any], Any] | None = None
 	enabled: bool = True
+	read_only: bool = False
 	mandatory: bool = False
 	dependencies: list[str | Callable[[], bool]] = field(default_factory=list)
 	dependencies_not: list[str] = field(default_factory=list)
@@ -74,31 +75,38 @@ class MenuItemGroup:
 		focus_item: MenuItem | None = None,
 		default_item: MenuItem | None = None,
 		sort_items: bool = False,
+		sort_case_sensitive: bool = True,
 		checkmarks: bool = False
 	) -> None:
 		if len(menu_items) < 1:
 			raise ValueError('Menu must have at least one item')
 
 		if sort_items:
-			menu_items = sorted(menu_items, key=lambda x: x.text)
+			if sort_case_sensitive:
+				menu_items = sorted(menu_items, key=lambda x: x.text)
+			else:
+				menu_items = sorted(menu_items, key=lambda x: x.text.lower())
 
-		if not focus_item:
-			focus_item = menu_items[0]
+		self._filter_pattern: str = ''
+		self._checkmarks: bool = checkmarks
 
-		if focus_item not in menu_items:
-			raise ValueError('Selected item not in menu')
-
-		self.menu_items: list[MenuItem] = menu_items
-		self.focus_item: MenuItem = focus_item
+		self._menu_items: list[MenuItem] = menu_items
+		self.focus_item: MenuItem | None = focus_item
 		self.selected_items: list[MenuItem] = []
 		self.default_item: MenuItem | None = default_item
 
-		self._checkmarks: bool = checkmarks
+		if not focus_item:
+			self.focus_first()
 
-		self._filter_pattern: str = ''
+		if self.focus_item not in self.items:
+			raise ValueError(f'Selected item not in menu: {focus_item}')
+
+	def add_item(self, item: MenuItem) -> None:
+		self._menu_items.append(item)
+		delattr(self, 'items')  # resetting the cache
 
 	def find_by_key(self, key: str) -> MenuItem:
-		for item in self.menu_items:
+		for item in self._menu_items:
 			if item.key == key:
 				return item
 
@@ -119,13 +127,13 @@ class MenuItemGroup:
 			item.preview_action = action
 
 	def set_focus_by_value(self, value: Any) -> None:
-		for item in self.menu_items:
+		for item in self._menu_items:
 			if item.value == value:
 				self.focus_item = item
 				break
 
 	def set_default_by_value(self, value: Any) -> None:
-		for item in self.menu_items:
+		for item in self._menu_items:
 			if item.value == value:
 				self.default_item = item
 				break
@@ -137,7 +145,7 @@ class MenuItemGroup:
 		if not isinstance(values, list):
 			values = [values]
 
-		for item in self.menu_items:
+		for item in self._menu_items:
 			if item.value in values:
 				self.selected_items.append(item)
 
@@ -146,7 +154,14 @@ class MenuItemGroup:
 
 	def index_focus(self) -> int | None:
 		if self.focus_item and self.items:
-			return self.items.index(self.focus_item)
+			try:
+				return self.items.index(self.focus_item)
+			except ValueError:
+				# on large menus (15k+) when filtering very quickly
+				# the index search is too slow while the items are reduced
+				# by the filter and it will blow up as it cannot find the
+				# focus item
+				pass
 
 		return None
 
@@ -157,11 +172,11 @@ class MenuItemGroup:
 	def get_max_width(self) -> int:
 		# use the menu_items not the items here otherwise the preview
 		# will get resized all the time when a filter is applied
-		return max([len(self.get_item_text(item)) for item in self.menu_items])
+		return max([len(self.get_item_text(item)) for item in self._menu_items])
 
 	@cached_property
 	def _max_items_text_width(self) -> int:
-		return max([len(item.text) for item in self.menu_items])
+		return max([len(item.text) for item in self._menu_items])
 
 	def get_item_text(self, item: MenuItem) -> str:
 		if item.is_empty():
@@ -198,8 +213,9 @@ class MenuItemGroup:
 	@cached_property
 	def items(self) -> list[MenuItem]:
 		pattern = self._filter_pattern.lower()
-		items = filter(lambda item: item.is_empty() or pattern in item.text.lower(), self.menu_items)
-		return list(items)
+		items = filter(lambda item: item.is_empty() or pattern in item.text.lower(), self._menu_items)
+		l_items = list(items)
+		return l_items
 
 	@property
 	def filter_pattern(self) -> str:
@@ -227,6 +243,8 @@ class MenuItemGroup:
 		if len(self.items) > 0:
 			if self.focus_item not in self.items:
 				self.focus_first()
+		else:
+			self.focus_item = None
 
 	def is_item_selected(self, item: MenuItem) -> bool:
 		return item in self.selected_items
@@ -261,51 +279,45 @@ class MenuItemGroup:
 			self.focus_item = last_item
 
 	def focus_prev(self, skip_empty: bool = True) -> None:
-		assert self.focus_item is not None
+		# e.g. when filter shows no items
+		if self.focus_item is None:
+			return
+
 		item = self._find_next_selectable_item(self.items, self.focus_item, -1)
 
 		if item is not None:
 			self.focus_item = item
 
 	def focus_next(self, skip_not_enabled: bool = True) -> None:
-		assert self.focus_item is not None
+		# e.g. when filter shows no items
+		if self.focus_item is None:
+			return
+
 		item = self._find_next_selectable_item(self.items, self.focus_item, 1)
 
 		if item is not None:
 			self.focus_item = item
 
-	def get_focus_index(self) -> int:
-		return self.items.index(self.focus_item)
-
 	def _find_next_selectable_item(
 		self,
 		items: list[MenuItem],
 		start_item: MenuItem,
 		direction: int
 	) -> MenuItem | None:
-		index = self.items.index(start_item)
+		start_index = self.items.index(start_item)
+		n = len(items)
 
-		start = index + direction
-		end = 0
+		current_index = start_index
+		for _ in range(n):
+			current_index = (current_index + direction) % n
 
-		if direction == 1:
-			end = len(items) + index
-		elif direction == -1:
-			if index == 0:
-				end = len(items) * direction
-			else:
-				end = index * direction
-
-		for idx in range(start, end, direction):
-			idx = idx % len(items)
-
-			if self._is_selectable(items[idx]):
-				return items[idx]
+			if self._is_selectable(items[current_index]):
+				return items[current_index]
 
 		return None
 
 	def is_mandatory_fulfilled(self) -> bool:
-		for item in self.menu_items:
+		for item in self._menu_items:
 			if item.mandatory and not item.value:
 				return False
 		return True
@@ -319,6 +331,8 @@ class MenuItemGroup:
 	def _is_selectable(self, item: MenuItem) -> bool:
 		if item.is_empty():
 			return False
+		elif item.read_only:
+			return False
 
 		return self.is_enabled(item)
 
